@@ -22,7 +22,7 @@ def download_file(url, root_dir=None, ext= None):
 def cache_file(url):
     rs = None
     try:
-        rs = get_dir('cached') + os.path.basename(url)
+        rs = os.path.join(get_dir('cached'), os.path.basename(url))
         if os.path.exists(rs):
             return rs #cached
         r = requests.get(url)
@@ -34,7 +34,7 @@ def cache_file(url):
     return rs
 
 def get_dir(dir):
-    tmp_download_path = tempfile.gettempdir() + "/"+dir+"/"
+    tmp_download_path = os.path.join(tempfile.gettempdir() ,dir)
     if not os.path.exists(tmp_download_path):
         os.makedirs(tmp_download_path)
     return tmp_download_path
@@ -69,8 +69,8 @@ def normal_audio(file_path, is_del=True):
             if stream['codec_type'] == "audio":
                 if stream['codec_name'] != "mp3" or int(stream['bit_rate']) != 128000 or int(
                         stream['sample_rate']) != 44100:
-                    tmp_file=get_dir('coolbg_ffmpeg') + str(uuid.uuid4())+".mp3"
-                    cmd = f"ffmpeg -i {file_path} -b:a 128000 -ar 44100 -c:a mp3 {tmp_file}"
+                    tmp_file=os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4())+".mp3")
+                    cmd = f"ffmpeg -i \"{file_path}\" -b:a 128000 -ar 44100 -c:a mp3 \"{tmp_file}\""
                     os.system(cmd)
                     if is_del:
                         os.remove(file_path)
