@@ -88,7 +88,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
             cnt_effect_vid += 1
             is_cont=False
             if comp.is_intro:
-                introPath = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-intro.mp4"
+                introPath = os.path.join(get_dir('coolbg_ffmpeg'),str(uuid.uuid4()) + "-intro.mp4")
                 rs = comp.get_clip()
                 if not rs.audio:
                     rs.close()
@@ -98,7 +98,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
                 is_cont = True
                 rs.close()
             if comp.is_outro:
-                outroPath = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-outro.mp4"
+                outroPath = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-outro.mp4")
                 rs = comp.get_clip()
                 if not rs.audio:
                     rs.close()
@@ -146,13 +146,13 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
             cnt_real_duration+=1
         #make intro composite
         if intro_time_real > 0:
-            tmp_path_composite_intro = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-comp-intro-vid.mp4"
+            tmp_path_composite_intro = os.path.join(get_dir('coolbg_ffmpeg'),str(uuid.uuid4()) + "-comp-intro-vid.mp4")
             tmp_clip = CompositeVideoClip(arr_composite).subclip(0, intro_time_real)
             tmp_clip.write_videofile(tmp_path_composite_intro, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
             tmp_clip.close()
 
-        tmp_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-final-vid.mp4"
-        tmp_path_maked_loop = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + "-final-vid.mp4"
+        tmp_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-final-vid.mp4")
+        tmp_path_maked_loop = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + "-final-vid.mp4")
         final_clip = CompositeVideoClip(arr_composite_no_intro).subclip(0, max_real_duration)
         final_clip.write_videofile(tmp_path, bitrate='4M', fps=24, codec='libx264', audio=False, logger=logger)
         #crop big video
@@ -336,7 +336,7 @@ class TextComp(Component):
 
     def get_clip(self):
         self.font_path = cache_file(self.font_url)
-        rs = TextClip(txt= self.text, font = self.font_path, fontsize=self.font_size, color=self.color,
+        rs = TextClip(txt= self.text, font = self.font_path.replace("\\","/"), fontsize=self.font_size, color=self.color,
                         bg_color = self.bg_color, size=(self.position['width'], self.position['height']),
                         stroke_color = self.stroke_color, stroke_width=self.stroke_width)
         return rs
