@@ -6,7 +6,7 @@ from moviepy.editor import *
 import urllib
 def download_audio(url,ext='mp3'):
     file_name = str(uuid.uuid4()) + "." + ext
-    rs = get_dir('download') + file_name
+    rs = os.path.join(get_dir('download'), file_name)
     ydl_opts = {
         'outtmpl': rs,
         'format': 'bestaudio/m4a',
@@ -20,9 +20,9 @@ def create_compilation_songs(data, job_id, mf_server):
     #7: deezer
     #8: link direct
     arr_songs=data
-    file_merg_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4())
+    file_merg_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()))
     file_merg = open(file_merg_path, "a")
-    final_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-final.mp3'
+    final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final.mp3')
     cnt_song=0
     try:
         for song in arr_songs:
@@ -64,12 +64,12 @@ def create_compilation_songs(data, job_id, mf_server):
                     song['local']= create_loop_audio_times(song['local'], song['repeat'])
 
                 if not "coolbg_ffmpeg" in song['local']:
-                    tmp_clip_path = get_dir('coolbg_ffmpeg') + str(uuid.uuid4()) + '-' + os.path.basename(song['local'])
+                    tmp_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-' + os.path.basename(song['local']))
                     shutil.copyfile(song['local'], tmp_clip_path)
                     os.remove(song['local'])
                     song['local']=tmp_clip_path
 
-                file_merg.write("file '%s'\n" % os.path.basename(song['local']))
+                file_merg.write("file '%s'\n" % song['local'])
                 cnt_song+=1
             except:
                 pass
